@@ -10,7 +10,7 @@ import html
 from collections import namedtuple, OrderedDict
 import math
 
-__version__ = '0.18.3'
+__version__ = '0.19.0'
 __author__ = 'Danny Lin'
 __author_email__ = 'danny0838@gmail.com'
 __homepage__ = 'https://github.com/danny0838/sts-lib'
@@ -786,11 +786,11 @@ class Trie(StsDict):
             return StsDictMatch(conv, pos, match_end)
         return None
 
-class StsListMaker():
-    """A class for compling a dictionary.
+class StsMaker():
+    """A class for making a dictionary.
     """
-    def make(self, config_name, base_dir=None, output_dir=None, skip_requires=False, quiet=False):
-        """Compile a dictionary according to config.
+    def make(self, config_name, base_dir=None, output_dir=None, skip_check=False, skip_requires=False, quiet=False):
+        """Make a dictionary according to config.
 
         Load dictionaries specified in config and generate a new dictionary.
 
@@ -824,13 +824,14 @@ class StsListMaker():
         # make the requested dicts
         for dict_ in config['dicts']:
             dest = os.path.join(output_dir or config_dir, dict_['file'])
-            format = dict_['format']
+            format = os.path.splitext(dest)[1][1:].lower()
             mode = dict_['mode']
+            sort = dict_.get('sort', False)
             files = [self.get_stsdict_file(f, base_dir=config_dir) if isinstance(f, str)
                 else [self.get_stsdict_file(i, base_dir=config_dir) for i in f]
                 for f in dict_['src']]
 
-            if not self.check_update(dest, files):
+            if not skip_check and not self.check_update(dest, files):
                 if not quiet: print(f'skip making (up-to-date): {dest}')
                 continue
 
@@ -847,14 +848,12 @@ class StsListMaker():
 
             os.makedirs(os.path.dirname(dest), exist_ok=True)
 
-            if format == 'list':
-                table.dump(dest)
+            if format == 'tlist':
+                Trie(table).dumpjson(dest, sort=sort)
             elif format == 'jlist':
-                table.dumpjson(dest)
-            elif format == 'tlist':
-                Trie(table).dumpjson(dest)
-            else:
-                raise ValueError(f'Specified format "{format}" is not supported.')
+                table.dumpjson(dest, sort=sort)
+            else:  # default: list
+                table.dump(dest, sort=sort)
 
         return dest
 
@@ -1133,10 +1132,11 @@ def main():
         """
         configs = args['config']
         dir = args['dir']
+        skip_check = args['force']
         quiet = args['quiet']
 
         for config in configs:
-            StsListMaker().make(config, output_dir=dir, quiet=quiet)
+            StsMaker().make(config, output_dir=dir, skip_check=skip_check, quiet=quiet)
 
     def convert(args):
         """Convert a file using the given config.
@@ -1152,7 +1152,7 @@ def main():
         input_encoding = args['in_enc']
         output_encoding = args['out_enc']
 
-        stsdict = StsListMaker().make(config, quiet=True)
+        stsdict = StsMaker().make(config, quiet=True)
         converter = StsConverter(stsdict, options)
 
         # read STDIN if no input file is specified
@@ -1229,6 +1229,8 @@ def main():
         help=make.__doc__, description=make.__doc__)
     parser_make.add_argument('config', nargs='+',
         help="""the config(s) to generate""")
+    parser_make.add_argument('--force', default=False, action='store_true',
+        help="""bypass update check and generate dicitonary(s) anyway""")
     parser_make.add_argument('-d', '--dir', default=None,
         help="""the directory to save the output (default: relative to config)""")
     parser_make.add_argument('-q', '--quiet', default=False, action='store_true',
